@@ -35,7 +35,7 @@ _cdll = ctypes.cdll.LoadLibrary(_dll_file)
 _cdll.MapMatching4GMNS.argtypes = [ctypes.c_int]
 
 
-def _optimal_MapMatching4GMNS_CAPI(mode):
+def mmg_CAPI(mode):
     '''Two modes:
         modes 0: reading trace.csv, then automaticically generate input_agent.csv and output agent.csv
         model 1: reading input_agent.csv, then output agent.csv and link_performance.csv
@@ -50,7 +50,7 @@ def _optimal_MapMatching4GMNS_CAPI(mode):
 
 #     import time
 #     start = time.time()
-#     _optimal_MapMatching4GMNS_CAPI(mode)
+#     mmg_CAPI(mode)
 #     end = time.time()
 
 #     print('MapMatching4GMNS time cost: %.6f seconds' % (end - start))
